@@ -12,7 +12,8 @@ function(RP.out # the result of a call to RPParallel
     Test.Class <- RP.out[n.val + 1:n.test, ]
   }
   else{Test.Class <- RP.out[n + 1:n.test, ]}
-  vote <- rowMeans(Test.Class, na.rm = TRUE)
+  if(n.test == 1){vote <- mean(Test.Class, na.rm = TRUE)}
+  if(n.test > 1){vote <- rowMeans(Test.Class, na.rm = TRUE)}
   Class  <- 1 + as.numeric(vote > alpha)
   return(Class)
 }
